// Display Panel for SpXZeigR
// Jeffrey J Weimer
// This works with SpXZeigR 4.0
// Revision History: $Revision: 509 $ on $Date: 2008-02-06 18:07:59 -0500 (Wed, 06 Feb 2008) $

#pragma rtGlobals=1
#pragma IgorVersion=6.0
#pragma version=4.00

#include "udFLStandardStructure", version = 1.04
#include "udFLStandardFunctions", version = 1.04

Function xzShowSpXPanel()
	variable restart

	if (strlen(WinList("udFL_Panel","","WIN:64"))!=0)
		DoWindow/F udFL_Panel
		return 0
	endif

	SVAR dff = root:Packages:SpXZeigR:DisplayPanelParams:displayfromfolder
	dff = ""
	
	udFLStandardPanel#ShowPanel(0)
	xzCreateDisplayTab()

end

Function xzCreateDisplayTab()

	SVAR dff = root:Packages:SpXZeigR:DisplayPanelParams:displayfromfolder
	SVAR dwc = root:Packages:SpXZeigR:DisplayPanelParams:displaywildcard
	SVAR idpm = root:Packages:SpXZeigR:DisplayPanelParams:initialDisplayPanelMode

	string dfSpectrumType, dfGraphMode
	variable dfSTn, dfGMn, dfdffn

	TabControl tb, tabLabel(1)=xzdis00, value=1
	
	dfSpectrumType = StringByKey("spectrumtype",idpm,"=")
	dfGraphMode = StringByKey("graphmode",idpm,"=")
	
	dfSTn = WhichListItem(dfSpectrumType,xzSpectrumTypesList())+1
	dfGMn =  WhichListItem(dfGraphMode,xzGraphModesList())+1

	// Display Tab
	// =====

	// Folder List
	
	if (strlen(dff)==0)
		dfdffn = 3
	else
		dfdffn = WhichListItem(dff,xzFolderList(1))+1
	endif
	PopupMenu flist_tb1,pos={20,39},size={122,20},title=xzdis00a,fSize=12
	PopupMenu flist_tb1, mode=dfdffn,popvalue=dff, value=#"xzFolderList(1)", proc=xz_popChangeDisplayFromFolder

	// File List

	PopupMenu spectrum_tb1,pos={20,65},size={87,20},title=xzdis00b,fSize=12
	dfdffn = WhichListItem(dff,xzFolderList(1))+1
	PopupMenu spectrum_tb1,mode=1,value=#"xzSpectraList(0)", proc=xz_popSelectDisplayTraces
	
	CheckBox xnegwc_tb1,pos={180,66}, size={60,20}, title="(-)", value=0

	// Wave Note
	
	Button wavenote_tb1, pos={200,65}, size={20,20}, title="?", fSize=10, proc=xz_bcShowWaveNote
	
	// Wildcard Input

	SetVariable wildcard_tb1,pos={20,92},size={185,17},title=xzdis00c,fSize=12
	SetVariable wildcard_tb1,value=dwc, proc=xz_svcValidateWildCard
			
	// Multitrace Control

	PopupMenu multitrace_tb1,pos={20,120},size={157,20},title=xzdis00d,fSize=12
	PopupMenu multitrace_tb1,mode=1,popvalue="On New",value= #"xzMultiTraceMenu()"

	// Spectrum Type
	
	PopupMenu type_tb1,pos={20,190},size={142,20},title=xzdis00e,fSize=12
	PopupMenu type_tb1,mode=dfSTn,value=#"xzSpectrumTypesList()", popValue=dfSpectrumType

	// Plotmode
	
	PopupMenu plotmode_tb1,pos={20,220},size={108,20},title=xzdis00f,fSize=12
	PopupMenu plotmode_tb1,mode=dfGMn,value=#"xzGraphModesList()", popValue=dfGraphMode

	CheckBox xloader_tb1,pos={20,165},size={87,20},title=xzdis00g
	CheckBox xloader_tb1,value=0, proc=xz_cbcCheckLoaderParams

	Button doboth,pos={84,285},size={140,20},title=xzdis00h, disable=1, proc=xz_bcDoBoth
	Button doboth, font="Geneva",fSize=14, fColor=(49151,49151,65535)

	udFLStandardPanel#PanelFillTab(1)
end

Function udFLPanelSetTab1(how)
	variable how
	
	if (how==1)
	
	// create things

		Button tb_doit, title=xzdis00i, userData="Display"
		ControlInfo flist_tb1
		if (V_value<3)
			PopupMenu spectrum_tb1 disable = 1
			PopupMenu multitrace_tb1 disable = 0
			SetVariable wildcard_tb1 disable = 1
			CheckBox xloader_tb1 disable=0	
			CheckBox xnegwc_tb1,disable=1
			Button wavenote_tb1 disable=1
			Button tb_doit disable = 1
			Button doboth disable=0
		else
			ControlInfo spectrum_tb1
			Button tb_doit disable=(cmpstr(S_value,"(no spectra)")==0)
			Button wavenote_tb1 disable=(V_value<3)
			SetVariable wildcard_tb1 disable=(V_value!=2)
			CheckBox xnegwc_tb1 disable=(V_value!=2)
			PopupMenu multitrace_tb1 disable=((V_value>2)||(cmpstr(S_value,"(no spectra)")==0))
			CheckBox xloader_tb1 disable=1
			Button doboth disable=1
		endif
	else
	
	// possibly remove things
	
		ControlInfo flist_tb1
		if ((V_flag>0)&& (V_value<3))
			Button tb_doit disable = 1
			Button doboth disable=0
		endif
	
	endif
	
	return 0
end

// load and display data

Function xz_bcDoBoth(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	SVAR lowl = root:Packages:StandardizedFileLoader:listofwavesloaded
	SVAR ltf =  root:Packages:StandardizedFileLoader:loadtofolder
	SVAR wtd = root:Packages:SpXZeigR:GraphParams:wavestodisplay
	SVAR dff = root:Packages:SpXZeigR:DisplayPanelParams:displayfromfolder
	
	STRUCT udFLStandardStructure udFL
	variable cm
	
	switch(ba.eventCode)
		case 2:
			wtd=""
			ControlInfo tb_closeme
			cm = V_value
			CheckBox tb_closeme value=0
			ba.UserData="Load"
			udFL_bcDoIt(ba)
			if (strlen(lowl)==0)
				DoAlert 0, xzStr07
				break
			endif
			wtd=lowl
			dff = ltf
			CheckBox tb_closeme value=cm
			ba.UserData="Display"
			udFL_bcDoIt(ba)			
	endswitch
	return 0
end

Function xzDisplayData()

//	SVAR llowl = root:Packages:StandardizedFileLoader:listofwavesloaded

	SVAR wtd = root:Packages:SpXZeigR:GraphParams:wavestodisplay

	SVAR dwl = root:Packages:SpXZeigR:DisplayPanelParams:displaywavelist
	SVAR dwc = root:Packages:SpXZeigR:DisplayPanelParams:displaywildcard

//	SVAR dff = root:Packages:SpXZeigR:DataPanelParams:displayfromfolder
//	SVAR lfn = root:Packages:SpXZeigR:DataPanelParams:loadfunctionname
	NVAR spt = root:Packages:SpXZeigR:GraphParams:spectrumtype
	NVAR grm = root:Packages:SpXZeigR:GraphParams:graphmode
	
//	NVAR lnu = root:Packages:SpXZeigR:DataPanelParams:loadnameusing
	NVAR dmt = root:Packages:SpXZeigR:DisplayPanelParams:displaymultitrace

	if (strlen(wtd)==0)
		ControlInfo spectrum_tb1
		strswitch(S_Value)
			case "(no spectra)":
				DoAlert 0, xzdia00a
				return 0
				break
			case "All":
				wtd = xzSpectraList(1)
				break
			case "Match WildCard":
				wtd = ListMatch(xzSpectraList(1),dwc)
				ControlInfo xnegwc_tb1
				if (V_value)
					wtd = RemoveFromList(wtd,xzSpectraList(1))
				endif
				break
			default:
				dwl = S_Value
		endswitch		
		if (strlen(wtd)==0)
			DoAlert 0, xzdia00a
			return 0
		endif
	endif
	
	ControlInfo type_tb1
	spt = V_value
	ControlInfo plotmode_tb1
	grm = V_value
	ControlInfo multitrace_tb1
	dmt = V_Value
//	if (strlen(llowl)!=0)
//		dwl = llowl				
//	endif
	xzDisplaySpectra()
	wtd =""				
	return 0

end

// change things when display folder is changed

Function xz_popChangeDisplayFromFolder(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa

	SVAR dff = root:Packages:SpXZeigR:DisplayPanelParams:displayfromfolder
	SVAR lff = root:Packages:SpXZeigR:DisplayPanelParams:loadtofolder
	
	switch( pa.eventCode )
		case 2:
		
			// display from load
			
			if (pa.popNum < 3)
				PopupMenu flist_tb1 mode = 1
				PopupMenu spectrum_tb1 disable=1
				PopupMenu multitrace_tb1 disable=0
				Button tb_doit disable=1
				Button doboth disable=0
				CheckBox xloader_tb1 disable=0
				CheckBox xnegwc_tb1,disable=1
				SetVariable wildcard_tb1 disable = 1
				Button wavenote_tb1 disable=1
				dff = "root"
				break
			endif
			dff = pa.popStr
			PopupMenu spectrum_tb1 mode=1, disable=0
			ControlInfo spectrum_tb1
			PopupMenu multitrace_tb1 disable=(cmpstr(S_value,"All")!=0)
			Button tb_doit disable=(cmpstr(S_value,"(no spectra)")==0)
			SetVariable wildcard_tb1 disable=(cmpstr(S_value,"Match WildCard")!=0)
			CheckBox xnegwc_tb1,disable=(cmpstr(S_value,"Match WildCard")!=0)
			Button wavenote_tb1 disable=(V_value<2)
			Button doboth disable=1
			CheckBox xloader_tb1 disable=1
			PopupMenu type_tb1 disable=0
			CheckBox xloader_tb1 value=0
			break
	endswitch

	return 0
End

// change things when file list is changed

Function xz_popSelectDisplayTraces(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa
	
	SVAR dff = root:Packages:SpXZeigR:DisplayPanelParams:displayfromfolder
	SVAR swn = root:Packages:SpXZeigR:DisplayPanelParams:selectedwavenote
	
	string wname = "root:"
		
	switch( pa.eventCode )
		case 2:
			swn = ""
			Button wavenote_tb1 disable=1
			CheckBox xnegwc_tb1 disable=1
			SetVariable wildcard_tb1 disable=1
			PopupMenu multitrace_tb1,title=xzdis00d
			switch(pa.popNum)
				case 1:
//					PopupMenu multitrace_tb1 disable=(cmpstr(pa.popStr,"All")!=0)	
					break
				case 2:
					SetVariable wildcard_tb1 disable=0	
//					PopupMenu multitrace_tb1 disable=0
					CheckBox xnegwc_tb1 disable=0
					break
				case 3:
					PopupMenu spectrum_tb1 mode=1
//					PopupMenu multitrace_tb1 disable=0	
					break
				default:
					PopupMenu multitrace_tb1, title=xzdis00j
					Button wavenote_tb1 disable=0
					if (cmpstr(dff,"root")==0)
						wname += pa.popStr
					else
						wname += dff + ":" + pa.popStr
					endif
					swn = note($wname)
			endswitch
			break
	endswitch

	return 0
End

// validate wild card

Function xz_svcValidateWildCard(sv) : SetVariableControl
	STRUCT WMSetVariableAction &sv

	SVAR dwc = root:Packages:SpXZeigR:DataPanelParams:displaywildcard
	
	variable trn
	
	switch(sv.eventCode)
		case 2:
			if ((strsearch(sv.sval,":",0)>0)||(strsearch(sv.sval," ",0)>0))
				dwc = "INVALID : or Spaces!"
				ControlUpdate wildcard_tb1
				trn = ticks
				do
				while((ticks-trn)<90)
				dwc=""
				SetVariable wildcard_tb1 activate
			endif
			break	
	endswitch
	
	return 0
End

// show wave note

Function xz_bcShowWaveNote(bc) : ButtonControl
	STRUCT WMButtonAction &bc

	// set notebook size
		
	NVAR scrw = root:Packages:ScreenSizer:scrwpnt
	NVAR scrh = root:Packages:ScreenSizer:scrhpnt
	NVAR scrr = root:Packages:ScreenSizer:scrright
	NVAR scrt = root:Packages:ScreenSizer:scrtop
	
	variable pleft, ptop, pwidth, pheight
	
	string wnote, wname, fname, wnotem

	wnotem = "Wave Note for "
	
	switch(bc.eventCode)
		case 2:
			ControlInfo flist_tb1
			if (cmpstr(S_value,"root")==0)
				fname = "root:"
			else
				fname = "root:" + S_value + ":"
			endif
			wnotem += fname
			ControlInfo spectrum_tb1
			wname = fname + S_value
			wnote = note($wname)
			if (strlen(wnote)==0)
				wnote = "NO NOTES EXIST FOR THIS DATA"
			endif
			
			// kill prior notebook
			
			if (strlen(WinList("xzWaveNote","","WIN:16"))!=0)
				KillWindow xzWaveNote
			endif
			
			pleft = 0.5*scrr*scrw
			ptop = scrt*scrh
			pwidth = pleft+320
			pheight = ptop+200
			
			NewNoteBook/F=0/K=1/N=xzWaveNote/W=(pleft,ptop,pwidth,pheight)
			Notebook xzWaveNote status={wnotem,0}
			Notebook xzWaveNote text=wnote	
			
			break
	endswitch
	
	return 0
end
