// StartUp Routines for SpXZeigR
// This works with SpXZeigR 4.0
// Jeffrey J Weimer
// SVN History: $Revision: 3 $ on $Date: 2007-12-27 17:12:31 -0500 (Thu, 27 Dec 2007) $

#pragma rtGlobals=1
#pragma IgorVersion=6.03
#pragma version=4.00

#include "udStFiLrXML"
#include "ScreenSizer", version >=1.10

// menu builder functions

Function/S xzMainMenuList(itemNumber)
	variable itemNumber

	variable started = NumVarOrDefault("root:Packages:SpXZeigR:Globals:xzstarted",0)

	if (started==0)
		if (itemNumber == 1)
			return xzmenu00
		endif
	else
		switch(itemNumber)
			case 1:
				return xzmenu01
				break
			case 2:
				return (xzmenu02 + "/S1")
				break
			case 99:
				return (xzmenu99)
		endswitch
	endif
end

// main menu (dynamic)

Menu "SpXZeigR", dynamic
	xzMainMenuList(1), /Q, StartUpSpXZeigR()
	"--"
	xzMainMenuList(2),/Q, xzShowSpXPanel()
	"--"
	SubMenu "Misc"
		"Change Paradigm",/Q, ChangeSpXParadigm()
		xzMainMenuList(99),/Q, UnloadSpXZeigR()
		 "About SpXZeigR",/Q
	End
End

// start up / restart function

Function StartUpSpXZeigR()

	string cdf, hstr
	variable restart
	
	cdf = GetDataFolder(1)
	
	if (DataFolderExists("root:Packages:SpXZeigR")==0)
	
		// initalize from clean start
		
		NewDataFolder/O/S root:Packages
		NewDataFolder/O/S SpXZeigR
		hstr =  "SpXZeigR Started " + date() + " " + time()
		ScreenSizer#Initialize(1)
		restart = 0
	else
	
		hstr =  "SpXZeigR (re)Started " + date() + " " + time()
		SetDataFolder root:Packages:SpXZeigR
		ScreenSizer#Initialize(0)	
		restart = 1
	endif
		
	// set/initialize the working parameters
	
	xzSettheGlobals()
	xzSettheGraphParams()
	xzSettheDisplayPanelParams()
	
	// organize the GUI
	
	ScreenSizer#MoveCmdWindow(0,80,60,100)
	udFLStandardPanel#ShowPanel(restart)
	xzCreateDisplayTab()
//	udFLStandardPanel#CreateNewTab()
	
	SetDataFolder $cdf
	xzPrintHistory(hstr)
	
	DoWindow/F xzDataPanel
	return 0
End

// Set the globals

Static Function xzSettheGlobals()

	NewDataFolder/O/S Globals
	variable/G xzstarted=1, xzdefaultSpecType
	string/G xzpathdata, xzpathstorage, xzverbose
	string/G tStr

	string lStr, tmpStr
	variable tmpN
	
	STRUCT udFLStandardStructure udFL
	udFLZeroStructure(udFL)
			
	// load the default paradigm
	
	tmpStr = FunctionPath("")
	tmpN = ItemsInList(tmpStr,":")
	
	tmpStr = RemoveListItem(tmpN-1,tmpStr,":")
	tmpStr = RemoveListItem(tmpN-2,tmpStr,":")
	
	udFL.pathStr = tmpStr + "XMLFiles:"
	udFL.fileList = "preferences.xsl;DEFAULTpreferences.xml;"

	udFL.userCtrl = 1
	udFL.toFolder = "Packages:SpXZeigR:Globals"
	udFL.reportCtrl = -1
	udStFiLrXML(udFL)
	
	// load the user defined paradigm

	udFL.pathStr = ""
	udFL.fileList = tmpStr + "XMLFiles:preferences.xsl;"
	udFL.fileList += tmpStr + "localizations:preferences.xml"

	udFL.userCtrl = 1
	udFL.toFolder = "Packages:SpXZeigR:Globals"
	udFL.reportCtrl = -1
	udStFiLrXML(udFL)
	
	SVAR xStr = defaultParadigm
	lStr = "Paradigm" + xStr
	SVAR tStr = $lStr
	
	// store the path settings and verbose mode
	
	xzpathstorage = StringByKey("pathstorage",tStr,"=")
	xzpathdata = StringByKey("pathdata",tStr,"=")
	xzverbose = StringByKey("verbose",tStr,"=")
	
	// store the screen settings
	
	variable scrleft, scrtop, scrright, scrbottom

	scrleft = NumberByKey("screenleft",tStr,"=")
	scrtop = NumberByKey("screentop",tStr,"=")
	scrright = NumberByKey("screenright",tStr,"=")
	scrbottom = NumberByKey("screenbottom",tStr,"=")
	
	ScreenSizer#SetFrame(scrleft,scrtop,scrright,scrbottom)
	
	// return
	
	SetDataFolder root:Packages:SpXZeigR
	
	return 0

end

// Set the graph parameters

Static Function xzSettheGraphParams()

	NewDataFolder/O/S GraphParams
	
	variable/G spectrumtype=1,graphmode=1, ngraphs=0
	string/G wavestodisplay=""

	NewDataFolder/O/S root:Packages:SpXZeigR:GraphParams:SpectrumTypes
	xzInitSpectrumTypes()

	NewDataFolder/O/S root:Packages:SpXZeigR:GraphParams:GraphModes
	xzInitGraphModes()
	DefaultFont/U $xzDefaultGraphFont

	SetDataFolder root:Packages:SpXZeigR
	return 0
End

// set the display panel parameters

Static Function xzSettheDisplayPanelParams()

	SVAR dT = root:Packages:SpXZeigR:GraphParams:SpectrumTypes:xzdefaultType

	NewDataFolder/O/S DisplayPanelParams
	
	string/G displayfromfolder="root", displaywavename=""
	string/G displaywavelist="", displaywildcard=""
	variable/G displaymultitrace=1
	string/G initialDisplayPanelMode=""
	
	// initialize the opening state of the display panel
	
	xzInitDisplayPanelMode()
	
	initialDisplayPanelMode += "spectrumtype=" + dT +";"

	SetDataFolder root:Packages:SpXZeigR
	return 0
End

// change paradigm

Function ChangeSpXParadigm()

	SVAR dP = root:Packages:SpXZeigR:Globals:defaultParadigm
	string pList = "", xL = "", fList="No;Yes;", cdf=""
	variable wP, ic = 0, forceIt
	do
		xL = GetIndexedObjName("root:Packages:SpXZeigR:Globals",3, ic)
		if (strlen(xL)==0)
			break
		endif
		if (stringmatch(xL,"Paradigm*"))
			pList += ReplaceString("Paradigm",xL,"") +";"
		endif
		ic += 1
	while(1)
	
	Prompt wP, "Select Paradigm", popup pList
	Prompt forceIt, "Force update (reload) of current paradigm?", popup fList
	DoPrompt "Shift Paradigm", wP, forceIt
	
	if (V_flag)
		return 0
	endif
	
	xL = StringFromList(wP-1,pList)
	if ((cmpstr(xL,dP)==0) && (forceIt==1))
		return 0
	endif
	
	if (forceIt==2)
		cdf = GetDataFolder(1)
		SetDataFolder root:Packages:SpXZeigR
		xzSettheGlobals()
		SetDataFolder $cdf
	endif
	
	xzShiftParadigm(xL)
	dP = xL
	
	return 0

end

// change paradigm (preferences)

Static Function xzShiftParadigm(xL)
	string xL
	
	SVAR vb = root:Packages:SpXZeigR:Globals:xzverbose
	SVAR pd = root:Packages:SpXZeigR:Globals:xzpathdata
	SVAR ps = root:Packages:SpXZeigR:Globals:xzpathstorage
	
	variable sl, st, sr, sb
	
	string hstr
	string psS = "root:Packages:SpXZeigR:Globals:Paradigm" + xL[0,strlen(xL)-1]
	
	SVAR tStr = $psS
	
	ps = StringByKey("pathstorage",tStr,"=")
	pd = StringByKey("pathdata",tStr,"=")
	vb = StringByKey("verbose",tStr,"=")

	sl = NumberByKey("screenleft",tStr,"=")
	st = NumberByKey("screentop",tStr,"=")
	sr = NumberByKey("screenright",tStr,"=")
	sb = NumberByKey("screenbottom",tStr,"=")

	ScreenSizer#Initialize(1)
	ScreenSizer#SetFrame(sl,st,sr,sb)
	ScreenSizer#MoveCmdWindow(0,80,60,100)

	udFLStandardPanel#ShowPanel(1)
	hstr =  "SpXZeigR Paradigm Shift: " + xL[0,strlen(xL)-1] +" " + date() + " " + time()
	xzPrintHistory(hstr)
	return 0
end

// remove package

Function UnloadSpXZeigR()

	if (strlen(WinList("udFL_Panel","","WIN:64"))!=0)
		KillWindow udFL_Panel
	endif
	string hstr =  "SpXZeigR Unloaded " + date() + " " + time()
	xzPrintHistory(hstr)
	Execute/P/Q/Z "DELETEINCLUDE \"SpXZeigR\""
	KillDataFolder/Z root:Packages:SpXZeigR
	Execute/P/Q/Z "COMPILEPROCEDURES"
	
	return 0
end

// initialize the spectrum types

Static Function xzInitSpectrumTypes()

	STRUCT udFLStandardStructure udFL
	udFLZeroStructure(udFL)
	
	string tmpStr
	variable tmpN
				
	// load the defaults
	
	tmpStr = FunctionPath("")
	tmpN = ItemsInList(tmpStr,":")
	
	tmpStr = RemoveListItem(tmpN-1,tmpStr,":")
	tmpStr = RemoveListItem(tmpN-2,tmpStr,":")
	
	udFL.pathStr = tmpStr + "XMLFiles:"
	udFL.fileList = "spectroscopies.xsl;DEFAULTspectroscopies.xml;"

	udFL.userCtrl = 1
	udFL.toFolder = "Packages:SpXZeigR:GraphParams:SpectrumTypes"
	udFL.reportCtrl = -1
	udStFiLrXML(udFL)
	
	// load the user defined

	udFL.pathStr = ""
	udFL.fileList = tmpStr + "XMLFiles:spectroscopies.xsl;"
	udFL.fileList += tmpStr + "localizations:spectroscopies.xml"

	udFL.userCtrl = 1
	udFL.toFolder = "Packages:SpXZeigR:GraphParams:SpectrumTypes"
	udFL.reportCtrl = -1
	udStFiLrXML(udFL)
	
	return 0

end