// SpectrumStats
// J J Weimer
// History: $Revision: 445 $ on $Date: 2008-01-10 17:03:43 -0500 (Thu, 10 Jan 2008) $
//
// plug-in module for SpXZeigR

#pragma rtGlobals=1

Static Structure SpectrumStatsGlobals
	string mode1Prompt
	string mode1Menu
	variable mode1Ctrl
	string mode2Prompt
	string mode2Menu
	variable mode2Ctrl
	variable repeatCtrl	
EndStructure

Function ssIntegratePeak()

	string cdf = GetDataFolder(1)
	NewDataFolder/O/S ssIntegratePeakResults
	
	variable rtv, parea, ic
	
	string sList = "All;" + TraceNameList("",";",1)
	string sNameIt = ""
	
	Prompt rtv,"Select the spectrum to integrate", popup, sList
	Prompt sNameIt, "Store the resultant integration wave as root:ssIntegratePeakResults: ..."
	DoPrompt "Spectrum Selection", rtv, sNameIt
	if (V_flag)
		return 0
	endif

	STRUCT SpectrumStatsGlobals ssGS
	
	ssGS.repeatCtrl = 0
	if (rtv!=1)
		wave swave = WaveRefIndexed("",rtv-2,1)
		if (waveexists(swave)==0)
			return 0
		endif
		parea = GetIntegral(swave,ssGS)
		print NameofWave(swave), parea
	else
		NewDataFolder/O/S tmp
		rtv = ItemsInList(sList) - 1
		make/O/N=(rtv)/T ssIP_name = ""
		make/O/N=(rtv) ssIP_value = 0
		wave swave = WaveRefIndexed("",0,1)
		if (waveexists(swave)==0)
			return 0
		endif
		ssIP_name[0] = NameofWave(swave)
		ssIP_value[0] = GetIntegral(swave, ssGS)
		ssGS.repeatCtrl =1
		for (ic=1;ic<rtv;ic+=1)
			wave swave = WaveRefIndexed("",ic,1)
			if (waveexists(swave)==0)
				return 0
			endif
			ssIP_name[ic] = NameofWave(swave)
			ssIP_value[ic] = GetIntegral(swave, ssGS)
		endfor
		SetDataFolder ::
		duplicate/O/T :tmp:ssIP_name ssIP_name
		duplicate/O :tmp:ssIP_value ssIP_value, $sNameIt
		if (!WinType("ssIP_Table"))
			edit/N=ssIP_Table ssIP_name, ssIP_value as "Integration Results"
		else
			DoWindow/F ssIP_Table
		endif
		ModifyTable title(ssIP_name)="spectrum",title(ssIP_value)=sNameIt	
		KillDataFolder tmp
	endif
	
	SetDataFolder $cdf
	
	return 0
end

Static Function GetIntegral(swave,ssGS)
	wave swave	
	STRUCT SpectrumStatsGlobals &ssGS
	
	if (!ssGS.repeatCtrl)
		ssGS.mode1Prompt="Set the integration method"
		ssGS.mode1Menu="Normal Rectangular;Trapezoidal;Modified Rectangular;"
		ssGS.mode2Prompt="Set the background subtraction method"
		ssGS.mode2Menu="None;Horizontal Line;Straight Line;"
		if (ssSetMode(ssGS)<0)
			return 0
		endif
	endif
	
	string dwave = NameofWave(swave)+"_sstmp"
		
	integrate/METH=(ssGS.mode1Ctrl-1) swave /D=$dwave
	
	wave idwave = $dwave
	variable vint
	vint = abs(idwave[pcsr(B)] - idwave[pcsr(A)])
	
	switch(ssGS.mode2Ctrl)
		case 1:
			break		
		case 2:
			vint += -abs(pcsr(B)-pcsr(A))*min(abs(swave[pcsr(B)]),abs(swave[pcsr(A)]))
			break
		case 3:
			vint += -abs(pcsr(B)-pcsr(A))*min(abs(swave[pcsr(B)]),abs(swave[pcsr(A)]))
			vint += -abs(pcsr(B)-pcsr(A))*abs(swave[pcsr(B)] - swave[pcsr(A)])/2
			break
	endswitch
		
	killwaves/Z dwave
	return vint

end

Static Function ssSetMode(ssGS)
	STRUCT SpectrumStatsGlobals &ssGS
	
	variable rtv1, rtv2
	Prompt rtv1, ssGS.mode1Prompt, popup, ssGS.mode1Menu
	Prompt rtv2, ssGS.mode2Prompt, popup, ssGS.mode2Menu
	DoPrompt "Select the Settings", rtv1, rtv2
	if (V_flag)
		return -1
	endif
	ssGS.mode1Ctrl = rtv1
	ssGS.mode2Ctrl = rtv2
	return 0
end